
/* *************************************************************************** */
/*                This do.file replicates the paper:                           */
/*			    "Ethnic diversity, social sanctions, and public goods in Kenya"*/
/*			      by "Edward Miguel & Mary Kay Gugerty"                        */
/*			      published in "Journal of Public Economics, 2005"             */
/* *************************************************************************** */


/* *************************************************************************** */
/* *********************    -FIRST STEPS-    ********************************* */
/* *************************************************************************** */
clear
set more off
set mem 10g

/* CHANGE TO REFLECT WORKING DIRECTORY */
cd "C:\Users\Elisa Cascardi\Desktop\Ethnic Diversity_Replication"

/*do not change - looking in data folder */
cd data\

capture log using kenya-ethnic, replace text


/* *************************************************************************** */
/* *********************    -DATA MANIPULATION & TABLES-    ****************** */
/* *************************************************************************** */
	
/* Ethnic Diversity and School Funding in Kenya - Version 5.0  */

/* SEE WATER-ANALYSIS.DO FOR TABLES 9 & 10 */

/* Construct SC/PTA meeting minute variables, January 2002 */

/* NUMBER OF MEETINGS */

insheet using mtgs98_jan02.csv
sort schoolid
save f1, replace
clear

insheet using mtgs99_jan02.csv
sort schoolid
merge schoolid using f1
tab _merge  
drop _merge
/* String --> numeric */
rename sc99_mins temp
gen sc99_mins = real(temp)
drop temp

rename sc99_mtgs temp
gen sc99_mtgs = real(temp)
drop temp

/* For several schools missing SC meetings information, but with minutes data, I have assumed
	that the total number of meetings is the number of meetings with minutes data */
/* This is only the case for certain schools in 1998, but for none in 1999 - 23jan01*/
replace sc98_mtgs=1 if schoolid==106
replace sc98_mtgs=1 if schoolid==124
replace sc98_mtgs=4 if schoolid==175 
replace sc98_mtgs=6 if schoolid==181 

replace pta98_mtgs=1 if schoolid==121 
replace pta98_mtgs=4 if schoolid==175 
replace pta98_mtgs=8 if schoolid==181 


/* Create overall measures across types of minutes and years */ 
gen mtgs98 = sc98_mtgs + pta98_mtgs 
gen mtgs99 = sc99_mtgs + pta99_mtgs 
gen mtgs9899 = mtgs98 + mtgs99 

summ 
sort schoolid 
save mtgs9899_jan02, replace 
clear 

/* MEETING RESOLUTIONS RAW DATA */ 

/* ONLY USE IF ITEM==2? */ 

insheet using sc98_jan02.csv 
local i=0 
while `i'<=21 { 
	gen sc98_`i'=(sc98_code==`i') 
	local i=`i'+1 
	} 
summ 
tab sc98_item 
tab sc98_code 
collapse (count) sc98_tot=sc98_code (sum) sc98_0-sc98_21, by(schoolid) 
sort schoolid 
summ 
save f1, replace 
clear 


insheet using sc99_jan02.csv 
local i=0 
while `i'<=21 { 
	gen sc99_`i'=(sc99_code==`i') 
	local i=`i'+1 
	} 
summ 
tab sc99_item 
tab sc99_code 
collapse (count) sc99_tot=sc99_code (sum) sc99_0-sc99_21, by(schoolid) 
sort schoolid 
summ 
save f2, replace 
clear 


insheet using pta98_jan02.csv 
local i=0 
while `i'<=21 { 
	gen pta98_`i'=(pta98_code==`i') 
	local i=`i'+1 
	} 
summ 
tab pta98_item 
tab pta98_code 
collapse (count) pta98_tot=pta98_code (sum) pta98_0-pta98_21, by(schoolid) 
sort schoolid 
summ 
save f3, replace 
clear 


insheet using pta99_jan02.csv 
local i=0 
while `i'<=21 { 
	gen pta99_`i'=(pta99_code==`i') 
	local i=`i'+1 
	} 
summ 
tab pta99_item 
tab pta99_code 
collapse (count) pta99_tot=pta99_code (sum) pta99_0-pta99_21, by(schoolid) 
sort schoolid 
summ 
save f4, replace 
clear 


/* Create a single dataset */ 
use f1 
merge schoolid using f2 
tab _merge  
drop _merge 

sort schoolid 
merge schoolid using f3 
tab _merge  
drop _merge 

sort schoolid 
merge schoolid using f4 
tab _merge  
drop _merge 

sort schoolid 
save f1, replace 
clear 

use mtgs9899_jan02 
sort schoolid 
save mtgs9899_jan02, replace 
clear 

use f1 
merge schoolid using mtgs9899_jan02 
tab _merge  
drop _merge 


/* CONSTRUCT TYPES OF RESOLUTIONS VARIABLES */ 
/* SET TO ZERO IF NO MEETINGS HELD THAT YEAR */ 
foreach any in sc98 sc99 pta98 pta99 { 
	replace `any'_tot = 0 if (`any'_mtgs==0) 
	
	/* Parent sanctions or verbal pressure */ 
	gen `any'_psanct = `any'_5 + `any'_6 
	replace `any'_psanct = 0 if (`any'_mtgs==0) 

	/* Moral exhortations (aimed at all groups) */ 
	gen `any'_moral = `any'_3 + `any'_7 + `any'_12 + `any'_14 
	replace `any'_moral = 0 if (`any'_mtgs==0) 

	/* ANY Parent sanctions, Verbal pressure, OR Moral exhortations */ 
	gen `any'_press = `any'_1 + `any'_2 + `any'_3 ///
				+ `any'_5 + `any'_6 + `any'_7 ///
				+ `any'_10 + `any'_11 + `any'_12 ///
				+ `any'_14 
	replace `any'_press = 0 if (`any'_mtgs==0) 
	
	/* Conflict */ 
	gen `any'_confl = `any'_21 
	replace `any'_confl = 0 if (`any'_mtgs==0) 

	/* school administration, projects, elections, other */ 
	gen `any'_admin = `any'_0 + `any'_4 + `any'_8 + `any'_9 ///
			+ `any'_13 + `any'_15 + `any'_16 + `any'_17 + `any'_18 + `any'_19 + `any'_20 
	replace `any'_admin = 0 if (`any'_mtgs==0) 

	} 

foreach any in tot psanct moral press confl admin { 
	
	gen mnts98_`any' = sc98_`any' + pta98_`any' 
	gen mnts99_`any' = sc99_`any' + pta99_`any' 
	gen mnts9899_`any' = mnts98_`any' + mnts99_`any' 
	} 

for num 0/21: drop *_X 
summ 
sort schoolid 
save mnts9899_jan02, replace 
clear 


use mkg_mar00.dta 
collapse rethnic2, by (zoneid) 
sort zoneid 
save temp1, replace 
clear 

use distall_mar00 
sort zoneid 
save temp2, replace 

merge zoneid using temp1 
tab _merge 
drop _merge 
save temp1, replace 

/* Selection into SAP */ 
gen ICS = 0 
replace ICS = 1 if (sap>0 & sap<5) 
gen ICS_reth = ICS*rethnic2 

/* All schools */ 
summ e95_t t95 if (ICS~=. & zoneid~=. & rethnic2~=. & t95~=. & e95_t~=.) 






/* *************************************************************************** */
/* Table A1 APPENDIX: Selection into NGO assistance program in 1995 */
/* *************************************************************************** */

	label variable ICS "SAP"
	label variable rethnic2 "ELF"
	label variable ICS_reth "SAP*ELF"


regress e95_t ICS if (ICS~=. & zoneid~=. & rethnic2~=. & t95~=. & e95_t~=.), robust cluster(zoneid)
estimates store m1	
regress e95_t ICS rethnic2 ICS_reth if (ICS~=. & zoneid~=. & rethnic2~=. & t95~=. & e95_t~=.), robust cluster(zoneid)
estimates store m2
regress t95 ICS if (ICS~=. & zoneid~=. & rethnic2~=. & t95~=. & e95_t~=.), robust cluster(zoneid)
estimates store m3
regress t95 ICS rethnic2 ICS_reth if (ICS~=. & zoneid~=. & rethnic2~=. & t95~=. & e95_t~=.), robust cluster(zoneid)
estimates store m4

outreg2 [m1] using Table_A1.doc, replace title("Table A1" , "Selection into NGO assistance program in 1995") ctitle("1995 Pupils enrollment" , "(District Educational" , " Office records)" , "OLS") stats(coef se) dec(2) sdec(1)  bdec(1) paren(se) aster(coef) addstat(Root MSE, e(rmse)) nocons addnote("SAP: Indicator for selection into NGO assistance program" , "ELF: Zonal residential ELF across tribes in 1996" , "SAP*ELF: (Indicator for selection into NGO assistance program)*(zonal residential ELF across tribes in 1996") label
outreg2 [m2] using Table_A1.doc, append title("Table A1" , "Selection into NGO assistance program in 1995") ctitle("OLS") stats(coef se) dec(2) sdec(1)  bdec(1) paren(se) aster(coef) addstat(Root MSE, e(rmse)) nocons label
outreg2 [m3] using Table_A1.doc, append title("Table A1" , "Selection into NGO assistance program in 1995") ctitle("1995 Average government", "exam result, Grades 68",  "OLS") stats(coef se) dec(2) sdec(1) bdec(1) paren(se) aster(coef) addstat(Root MSE, e(rmse)) nocons label
outreg2 [m4] using Table_A1.doc, append title("Table A1" , "Selection into NGO assistance program in 1995") ctitle("OLS") stats(coef se) dec(2)  sdec(1)  bdec(1) paren(se) aster(coef) addstat(Root MSE, e(rmse)) nocons label
 
/* Check on enrollment by standard, for all schools and SAP schools */ 
summ e95* 
summ e95* if (sap>0 & sap<5) 
clear 






/*** TABLE 2?: 1996 school descriptive statistics ***/ 
use mkg_sep01 
sort schoolid 
save temp0, replace 
clear 

use mkg_mar00 
keep schoolid hmtchIV hmyrssch ze95_t zt95 
sort schoolid 
save temp1, replace 
clear 

use trib_jan00 
gen tempscf = (sccomm1f + sccomm2f + sccomm3f + sccomm4f + sccomm5f ///
	+ sccomm6f + sccomm7f + sccomm8f)/8 
gen lgrp2 = max(luhya, teso, luo) 

sort schoolid 
merge schoolid using temp1 
tab _merge 
drop _merge 

sort schoolid 
merge schoolid using temp0 
tab _merge 
drop _merge 

save temp1, replace 
clear 


/* Merge in new ethnicity data, from 1998 and 1999 Pupil Questionnaires */ 

/* 1998 SURVEY - DO NOT NEED (?? HUH ?? 23jan02 */ 
/* ALL SURVEYS (1996, 1998, 1999) */ 
use eth_9699 
keep schoolid elf1_ALL elf2_ALL elf3_ALL lgrp2_ALL 
sort schoolid 
save temp2, replace 
clear 

use temp1 
sort schoolid 
merge schoolid using temp2 
tab _merge  
drop _merge 
sort schoolid 
save temp1, replace 

/* REPLACE MISSING 1996 ETHNICITY VALUES WITH 1998/1999 ETHNICITY */ 
replace ethnic1 = elf1_ALL if ethnic1==. 
replace ethnic2 = elf2_ALL if ethnic2==. 
replace ethnic3 = elf3_ALL if ethnic3==. 
replace lgrp2 = lgrp2_ALL if lgrp2==. 
sort schoolid 
save temp1, replace 
clear 

/* GENERATE CROP, LIVESTOCK, EDUCATION, WORK, ASSET OWNERSHIP OUTCOMES */ 

/* NOT Raw data */ 
use pup_oct99 
keep schoolid pupid rzoneid ///
	watersou health majorfd whichcro tobacco religion sweetpot beans millet sugarcan ///
	cassava maize chickens goats cattle pigs sheep ///
	catholic cpk *educ *std *form *univ *work *othwk 
	

/* "rwater" takes on a value of one if the water source is tank or tap,
	ie, "good" sources of water */ 
gen rwater = 0 
replace rwater = . if (watersou=="" | watersou=="9" | watersou=="G") 
replace rwater = 1 if (watersou=="C" | watersou=="F")  
summ rwater 

/* "rhealthy" takes on a value of one if the respondent claims to be in "good" health */ 
gen rhealthy = . 
replace rhealthy = 0 if (health=="B" | health=="C" | health=="b") 
replace rhealthy = 1 if (health=="A" | health=="a") 

/* "ryuca" takes on a value of one if the major daily good is cassava ugali */ 
gen ryuca = . 
replace ryuca = 1 if (majorfd=="B" | majorfd=="b") 
replace ryuca = 0 if (majorfd=="A" | majorfd=="C" | majorfd=="D") 

/* "rtobacco" takes on a value of one if the HH grows tobacco */ 
gen rtobacco = 2 - tobacco 

/* "rsugarcan" takes on a value of one if the HH grows sugar cane */ 
gen rsugarcan = 2 - sugarcan 

/* "rcotton" takes on a value of one if the HH grows sugar cane */ 
gen rcotton = 0 
replace rcotton = 1 ///
	if (whichcro=="COTTON" | whichcro=="COTTON,COFFEE" | whichcro=="SORGHUM,COTTON") 

/* "rcashcrop" takes on a value of one if the HH grows either tobacco, sugar cane, or cotton */ 
gen rcashcrop = 0 
replace rcashcrop = . if (rtobacco==. | rsugarcan==. | rcotton==.) 
replace rcashcrop = 1 if (rtobacco==1 | rsugarcan==1 | rcotton==1) 

/* "rcatholic" takes on a value of one for Catholics, already created */ 
gen rcatholic = catholic 
/* "rcpk" takes on a value of one for CPK members, already created */ 
gen rcpk = cpk 

/* "rsweetpot" takes on a value of one if the HH grows sweet potato */ 
gen rsweetpot = 2 - sweetpot 

/* "rbeans" takes on a value of one if the HH grows beans */ 
gen rbeans = 2 - beans 

/* "rmillet" takes on a value of one if the HH grows millet */ 
gen rmillet = 2 - millet 

/* "rcassava" takes on a value of one if the HH grows cassava */ 
gen rcassava = 2 - cassava 

/* "rmaize" takes on a value of one if the HH grows maize */ 
gen rmaize = 2 - maize 

/* "rbanana" takes on a value of one if the HH grows banana */ 
gen rbanana = 0 
replace rbanana = 1 ///
	if (whichcro=="BANANAS" | whichcro=="BANANA" | whichcro=="BANANAS,TOMATOE" ///
		| whichcro=="BANANAS,YAMS" | whichcro=="BANANASG.NUTS") 

/* "rchicken" takes on a value of one if the HH has at least one chicken */ 
gen rchicken = 0 
replace rchicken = 1 if (chickens>0) 
replace rchicken = . if (chickens==.) 

/* "rgoat" takes on a value of one if the HH has at least one goat */ 
gen rgoat= 0 
replace rgoat = 1 if (goats>0) 
replace rgoat = . if (goats==. | goats==99 | goats==990) 

/* "rcattle" takes on a value of one if the HH has at least one cow */ 
gen rcattle = 0 
replace rcattle = 1 if (cattle>0) 
replace rcattle = . if (cattle==. | cattle==99) 

/* "rpig" takes on a value of one if the HH has at least one pig */ 
gen rpig = 0 
replace rpig = 1 if (pigs>0) 
replace rpig = . if (pigs==. | pigs==99) 

/* "rsheep" takes on a value of one if the HH has at least one sheep */ 
gen rsheep = 0 
replace rsheep = 1 if (sheep>0) 
replace rsheep = . if (sheep==. | sheep==99) 

/* "rlivest" takes on a value of one if the HH has at last one goat, cow, pig, or sheep */ 
/* The majority of "other livestock" are ducks or turkeys, which we will not count, same as chickens */ 
gen rlivest = 0 
replace rlivest = . if (rgoat==. | rcattle==. | rpig==. | rsheep==.) 
replace rlivest = 1 if (rgoat==1 | rcattle==1 | rpig==1 | rsheep==1) 

/* "rfyrsed" is years of father's educational attainment */ 
gen rfyrsed = . 
replace rfyrsed = 0 if fatheduc=="A" 
replace rfyrsed = fathstd if (fatheduc=="B" & fathstd>0 & fathstd<9) 
replace rfyrsed = 8 + fathform if (fatheduc=="C" & fathform>0 & fathform<7) 
replace rfyrsed = 15 if (fatheduc=="D" & fathuniv~="UNIVERSITY") 
replace rfyrsed = 17 if (fatheduc=="D" & fathuniv=="UNIVERSITY") 

/* "rmyrsed" is years of mother's educational attainment */ 
gen rmyrsed = . 
replace rmyrsed = 0 if motheduc=="A" 
replace rmyrsed = mothstd if (motheduc=="B" & mothstd>0 & mothstd<9) 
replace rmyrsed = 8 + mothform if (motheduc=="C" & mothform>0 & mothform<7) 
replace rmyrsed = 15 if (motheduc=="D" & mothuniv~="UNIVERSITY") 
replace rmyrsed = 17 if (motheduc=="D" & mothuniv=="UNIVERSITY") 

/* "rfformwk" is an indicator for if the father has a "formal" job,
	including factory worker, teacher, government, doctor, NGO, etc. */ 
/* BIG CHANGE FROM PREVIOUS VERSION: DO NOT CONSIDER "DO BUSINESS" FORMAL SECTOR,
	SINCE MOST OF THIS IS JUST PETTY TRADE 
	NEED TO NOTE THIS IN A FOOTNOTE IN THE PAPER */ 
gen rfformwk = . 
replace rfformwk = 0 ///
	if (fathwork=="A" | fathwork=="B" | fathwork=="D" | fathwork=="G" | fathwork=="H") 
replace rfformwk = 1 ///
	if (fathwork=="C" | fathwork=="E" | fathwork=="F" | ///
		(fathwork=="H" & (fatothwk=="BANK" | fatothwk=="COMPANYCLERK" | fatothwk=="DOCTOR" |  ///
		fatothwk=="ACCOUNTANT" | fatothwk=="ENGINEERING" | fatothwk=="KENYAARMY" | fatothwk=="KENYARAILWAYS" | /// 
		fatothwk=="MANAGER" | fatothwk=="PETROLSTATION" | fatothwk=="RAILWAYS" | fatothwk=="SECURICOR" | ///
		fatothwk=="VETRINARY" | fatothwk=="WITHNGO" | fatothwk=="CAPTAIN" | fatothwk=="CONDUCTOR"))) 

/* "rmformwk" is an indicator for if the mother has a "formal" job,
	including factory worker, teacher, government, doctor, NGO, etc. */ 
/* BIG CHANGE FROM PREVIOUS VERSION: DO NOT CONSIDER "DO BUSINESS" FORMAL SECTOR,
	SINCE MOST OF THIS IS JUST PETTY TRADE 
	NEED TO NOTE THIS IN A FOOTNOTE IN THE PAPER */ 
gen rmformwk = . 
replace rmformwk = 0 ///
	if (mothwork=="A" | mothwork=="B" | mothwork=="F") 
replace rmformwk = 1 ///
	if (mothwork=="C" | mothwork=="D" | mothwork=="E" | ///
		(mothwork=="F" & (motothwk=="DOCTOR" | motothwk=="HEALTHWORKER" | motothwk=="NURSE" | /// 
		motothwk=="TYPIST"))) 

summ r*formwk 
drop if schoolid==. 
save temp00, replace 

sort pupid 
save temppup_jan02, replace 

collapse ///
	rwater rhealthy ryuca ///
	rtobacco rsugarcan rcotton rcashcrop ///
	rsweetpot rbeans rmillet rcassava rmaize rbanana ///
	rlivest rgoat rcattle rpig rsheep ///
	rcatholic rcpk ///
	rfyrsed rmyrsed ///
	rfformwk rmformwk ///
	, by (rzoneid) 

sort rzoneid 
rename rzoneid zoneid 
save temp0, replace 
clear 

use temp1 
sort zoneid 

merge zoneid using temp0 
tab _merge  
drop _merge 
summ r* 

drop if schoolid==. 
sort schoolid 
save temp1, replace 
clear 


use temp00 

drop water ///
	tobacco sugarcan ///
	sweetpot beans millet cassava maize ///
	/* livest goat */ cattle /* pig */ sheep ///
	catholic cpk
	/* fyrsed myrsed
	fformwk mformwk */ 

rename rwater water 
rename rhealthy healthy 
rename ryuca yuca 
rename rtobacco tobacco 
rename rsugarcan sugarcan 
rename rcotton cotton 
rename rcashcrop cashcrop 
rename rsweetpot sweetpot 
rename rbeans beans 
rename rmillet millet 
rename rcassava cassava 
rename rmaize maize 
rename rbanana banana 
rename rlivest livest 
rename rgoat goat 
rename rcattle cattle 
rename rpig pig 
rename rsheep sheep 
rename rcatholic catholic 
rename rcpk cpk 
rename rfyrsed fyrsed 
rename rmyrsed myrsed 
rename rfformwk fformwk 
rename rmformwk mformwk 

collapse water healthy yuca tobacco sugarcan cotton cashcrop sweetpot beans millet cassava maize banana livest goat cattle pig sheep catholic cpk fyrsed myrsed fformwk mformwk ///
	, by (schoolid) 

drop if schoolid==. 
sort schoolid 
save temp00, replace 
clear 

use temp1 
sort schoolid 

merge schoolid using temp00 
tab _merge  
drop _merge 

drop if schoolid==. 
sort schoolid 
save temp1, replace 

clear 

/* INCORPORATE 1995, 1996 FINANCIAL DATA */ 
/* Created in file data_10dec01.do */ 
use schfin_9697 
summ 
sort schoolid 
save schfin_9697, replace 

use temp1 
merge schoolid using schfin_9697 
tab _merge  
drop _merge 

/* 	Total funds raised in 1995: funds_96
	Total fees not for DEO collected in 1995: totcolle_96
	Total fees for DEO collected in 1995: totkept_96
	Total donations (mainly from harambees) in 1995: donation_96

*/ 

gen fees_96 = totcolle_96 + totkept_96 
sort schoolid 
save temp1, replace 


/* MAKE SAP CONTROLS */ 
tab sap, gen(sap) 
drop sap sap4 
save temp1, replace 


/* Create new teacher quality measures */ 
/* Raw data */ 
use 96Teacher 
keep schoolid gender yrstch yrssch educatio 

gen tchsex = . 
replace tchsex = 1 if gender=="A" 
replace tchsex = 0 if gender=="B" 
drop gender 

replace yrstch = 1 if yrstch==0.75 

replace yrssch = "1" if ( yrssch=="10/12" | yrssch=="2/12" | yrssch=="6/12" | yrssch=="9/12") 
gen yrsschB =real(yrssch) 
drop yrssch 
rename yrsschB yrssch 

gen tchIV = 0 
replace tchIV = 1 if educatio=="B" 
replace tchIV = . if educatio=="6" | educatio=="9" 
drop educatio 

collapse yrs* tch*, by(schoolid) 
drop if schoolid>199 
sort schoolid 
save temp2, replace 

use temp1 
sort schoolid 
merge schoolid using temp2 
tab _merge 
drop _merge 
sort schoolid 

/* Include new meeting minutes, meetings data */ 
merge schoolid using mnts9899_jan02 
tab _merge  
drop _merge 
sort schoolid 
save temp1, replace 
clear 

/* Include new data, including new dimensions (dim1, dim2) from "SCALE.ADO" */ 
/* Created in gps-ethnic_13jun02.do, with new coordinates. */ 
use gps-ethnic_jun02 
keep schid elfA* sch_* dim1 dim2 totp_gps north east 
rename schid schoolid 
sort schoolid 
save temp2, replace 
clear 

use temp1 
sort schoolid 
merge schoolid using temp2, update replace 
tab _merge 
drop _merge 

replace elfA_5km = . if elfA==. 
gen rlgrp2 = max(rluhya, rteso, rluo) 
gen ethlin = 1 - lgrp2 
gen rethlin = 1 - rlgrp2 

/* Generate a missing data indicator - NOT RELATED TO ETHNIC DIVERSITY */ 
gen missing = 0 
replace missing = 1 if (ethnic2==. | sc98_press==. | elfA_5km==. | maize==. | funds_96==.) 
summ missing 
regress missing ethnic2 
regress missing rethnic2 

/* DROP DETAILED TEXTBOOK INFORMATION */ 
drop pp* 
drop if schoolid>199 

sort schoolid 
compress 
save temp1, replace 



/* SAVING DATASET */ 

/* GIVE THIS FILE ANOTHER NAME, TO BE USED IN THE TANZANIA COMPARISON */ 
save f_kenya, replace 






/* *************************************************************************** */
/* Table 3: School Descriptive Statistics                                      */
/* *************************************************************************** */

/* '96 PQD = 1996 Pupil Questionnaire data, '96 END = 1996 Exam Namelist data, '95 KS = 1995 (Kenyan Shillings) RFO = reported by field officers */
/* Relabling Variables */ 
	label variable rethnic2 "Zonal residential ELF across tribes,'96 PQD"
	label variable rlgrp2 "Proportion of largest ethnic group in zone,'96 PQD"
	label variable elf2_ALL "School ELF across tribes,'96 PQD"
	label variable elfA  "School ELF across tribes,'96 END"
	label variable elfA_5km "ELF across tribes for ...5km,'96 END"
	label variable largegrp "Proportion of largest ethnic group in school,'96 PQD"
	label variable funds_96 "Total local school funds collected per pupil,'95 KS"
	label variable donation_96  "Harambee donations collected per pupil,'95 KS"
	label variable fees_96  "School fees collected per pupil,'95 KS"
	label variable  pta2pup "Desks per pupil,1995"
	label variable  plat2pup "Pupil latrines per pupil,1995"
	label variable room2pup "Classrooms per pupil, 1995"
	label variable bks2pup "School-owned texts per pupil, 1995"
	label variable text2pup  "Private texts per pupil, 1995"
	label variable totstud "Pupil enrollment per primary school, 1996"
	
	//label variable ICS "Average score on 1996 NGO examination, grades 38 (in standard deviations)"
	label variable sc98_press "School record sanctions/verbal pressure,1997"
	label variable sc98_admin  "School record administrative activities,1997"
	label variable  pta98_mtgs  "Parent school meetings, 1997"
	label variable PRcoop "Parent cooperation from 0 to 1 (RFO),1998"
	label variable TCmoti "Teacher motivation from 0 to 1 (RFO),1998"
	label variable pup2tch "Pupilteacher ratio, 1996"
	label variable tchIV "Proportion teachers with high school education,1996"
	label variable yrstch  "Years of teaching experience, 1996"
	label variable tchsex "Proportion of male teachers, 1996"
	label variable north "Latitude (degrees north), GPS data"
	label variable east "Longitude (degrees east), GPS data"
	label variable sch_5km  "Number of other primary schools w/in 5 km,GPS data"

keep  maize ethnic2 rethnic2 rlgrp2  elf2_ALL elfA elfA_5km largegrp funds_96 donation_96 fees_96 pta2pup  plat2pup room2pup bks2pup text2pup totstud sc98_press sc98_admin pta98_mtgs PRcoop TCmoti pup2tch  tchIV yrstch tchsex north  east sch_5km  
summ
outreg2 if (ethnic2~=. & funds_96~=. & elfA~=. & sc98_press~=. & maize~=.)  using Table_3.doc, replace sum(log) dec(2) title("Table 3" , "Primary school descriptive statistics") eqdrop(max min) drop(maize ethnic2) sortvar(rethnic2 rlgrp2  elf2_ALL elfA elfA_5km largegrp funds_96 donation_96 fees_96 pta2pup  plat2pup room2pup bks2pup text2pup totstud sc98_press sc98_admin pta98_mtgs PRcoop TCmoti pup2tch  tchIV yrstch tchsex north  east sch_5km) addn("The file replicates 'Proportion of male teachers', while the paper published had 'Proportion of female teachers' = (1 - result replicated)") label

clear 






/* *************************************************************************** */
/* Table 2:  Pupil descriptive statistics, by ethnic group                     */ 
/* *************************************************************************** */

/* The child resides and attends school in different zones */ 
use temp1 
sort schoolid 
keep schoolid elfA* funds_96 sc98_press 
save temp2, replace 
clear 

use pup_oct99 
sort schoolid 
merge schoolid using temp2 
tab _merge 
drop _merge 

/* Need not drop if maize==. here, since we only have the 97 schools with pupil data */ 
drop if (funds_96==. | ethnic1==. | elfA==. | sc98_press==. /* | maize==. */ ) 
sort pupid 

merge pupid using temppup_jan02 
tab _merge  
drop _merge 


replace rdvid = . 
/* Amukura: Aremit/Chakol, Kaujakito, Kotur */ 
replace rdvid = 2 if (rzoneid==3 | rzoneid==16 | rzoneid==18) 
/* Angurai: Angurai, Chamasiri, Katakwa, Amagoro/Kocholia */ 
replace rdvid = 3 if (rzoneid==2 | rzoneid==13 | rzoneid==15 | rzoneid==17) 
/* Budalangi: Bunyala North, Bunyala South/Bunyala Central */ 
replace rdvid = 4 if (rzoneid==8 | rzoneid==9) 
/* Butula: Burinda, Butunyi, Marachi North, Tingolo */ 
replace rdvid = 5 if (rzoneid==10 | rzoneid==11 | rzoneid==19 | rzoneid==22) 
/* Funyula: Agenga/Nanguba, Bwiri, Funyula, Nambuku/Namboboto */ 
replace rdvid = 7 if (rzoneid==1 | rzoneid==12 | rzoneid==14 | rzoneid==21) 
/* Matayos: Bukhayo South, Mundika */ 
replace rdvid = 8 if (rzoneid==7 | rzoneid==20) 
/* Nambale: Bukhayo Central, Bukhayo East, Bukhayo North */ 
replace rdvid = 9 if (rzoneid==4 | rzoneid==5 | rzoneid==6) 

/* Attends school and lives in different zones (~~~) */ 
gen crsszone = . 
replace crsszone = 0 if zoneid==rzoneid 
replace crsszone = 1 if zoneid~=rzoneid 
replace crsszone = . if (zoneid==. | rzoneid==.) 



/* Check on numbers of questionnaires by standard */ 
tab std 
tab std if luhya==1 
tab std if teso==1 
tab std if luo==1 

	gen livehome = . 
replace livehome = 0 if (withmoth==2 & withfath==2) 
replace livehome = 1 if (withmoth==1 | withfath==1)

save temp_pup, replace 



	label variable age "Age in years"
	label variable rfyrsed  "Father, years of education"
	label variable rmyrsed "Mother, years of education"
	label variable rfformwk  "Fathers with formal employment"
	label variable rmformwk  "Mothers with formal employment"
	label variable latrine "Proportion latrine ownership"
	label variable ironroof "Proportion iron roof ownership"
	label variable rlivest  "Proportion livestock ownership"
	label variable rmaize  "Proportion cultivates corn (maize)"
	label variable  rcashcrop "Proportion cultivates cash crop"
	label variable  transfer "Attends school not closest to home"
	label variable crsszone "Resid. & school different geo zones"
	label variable  livehome "Lives with a parent"
	label variable sibling  "Average number of full siblings"
	label variable rcatholic "Proportion, Catholic"
	label variable luhya "Luhya"
	label variable teso "Teso"
	label variable luo "Luo"
	
	


keep pupid age mothaliv fathaliv latrine sibling ironroof transfer crsszone rfyrsed rmyrsed rfformwk rmformwk rlivest rcashcrop rmaize rcatholic ethnmiss luhya teso luo livehome
/* The child lives with at least one parent */ 

	label variable  livehome "Lives with a parent if at least one parent is alive" 
summ livehome if (mothaliv=="A" | fathaliv=="A") 
outreg2 if ((mothaliv=="A" | fathaliv=="A")) using Table_2.B.doc, replace sum(log) dec(2) title("Table 2" , "Pupil descriptive statistics by ethnic group") ctitle("Entire sample") eqdrop(N sd max min) keep(livehome) addn("1 = Entire Sample, 2 = Luhya pupils, 3 = Teso pupils, 4 = Luo pupils") label
summ livehome if ((mothaliv=="A" | fathaliv=="A") & luhya==1) 
outreg2 if ((mothaliv=="A" | fathaliv=="A") & luhya==1) using Table_2.B.doc, append sum(log) dec(2) title("Table 2" , "Pupil descriptive statistics by ethnic group") ctitle("Entire sample") eqdrop(N sd max min) keep(livehome) addn("1 = Entire Sample, 2 = Luhya pupils, 3 = Teso pupils, 4 = Luo pupils") label
summ livehome if ((mothaliv=="A" | fathaliv=="A") & teso==1) 
outreg2 if ((mothaliv=="A" | fathaliv=="A") & teso==1)  using Table_2.B.doc, append sum(log) dec(2) title("Table 2" , "Pupil descriptive statistics by ethnic group") ctitle("Entire sample") eqdrop(N sd max min) keep(livehome) addn("1 = Entire Sample, 2 = Luhya pupils, 3 = Teso pupils, 4 = Luo pupils") label
summ livehome if ((mothaliv=="A" | fathaliv=="A") & luo==1) 
outreg2 if ((mothaliv=="A" | fathaliv=="A")& luo==1) using Table_2.B.doc, append sum(log) dec(2) title("Table 2" , "Pupil descriptive statistics by ethnic group") ctitle("Entire sample") eqdrop(N sd max min) keep(livehome) addn("1 = Entire Sample, 2 = Luhya pupils, 3 = Teso pupils, 4 = Luo pupils") label


summ pupid age  latrine sibling ironroof transfer crsszone ///
	rfyrsed rmyrsed rfformwk rmformwk rlivest rcashcrop rmaize rcatholic livehome ///
	if ethnmiss==0 
outreg2 if ethnmiss==0 using Table_2.doc, replace sum(log) dec(2) title("Table 2" , "Pupil descriptive statistics by ethnic group") ctitle("Entire sample") eqdrop(N sd max min) keep(age latrine sibling ironroof transfer crsszone rfyrsed rmyrsed rfformwk rmformwk rlivest rcashcrop livehome rmaize rcatholic) sortvar(age rfyrsed rmyrsed rfformwk rmformwk latrine ironroof rlivest rmaize rcashcrop transfer crsszone livehome sibling rcatholic) addn("1 = Entire Sample, 2 = Luhya pupils, 3 = Teso pupils, 4 = Luo pupils") label


summ pupid age   latrine sibling ironroof transfer crsszone ///
	rfyrsed rmyrsed rfformwk rmformwk rlivest rcashcrop rmaize rcatholic livehome ///
	if luhya==1 
outreg2 if luhya==1 using Table_2.doc, append sum(log) dec(2) title("Table 2" , "Pupil descriptive statistics by ethnic group") ctitle("Luhya pupils") eqdrop(N sd max min) keep( age latrine sibling ironroof transfer crsszone rfyrsed rmyrsed rfformwk rmformwk rlivest rcashcrop livehome rmaize rcatholic) sortvar(age rfyrsed rmyrsed rfformwk rmformwk latrine ironroof rlivest rmaize rcashcrop transfer crsszone livehome sibling rcatholic) addn("1 = Entire Sample, 2 = Luhya pupils, 3 = Teso pupils, 4 = Luo pupils") label
	

summ pupid age   latrine sibling ironroof transfer crsszone ///
	rfyrsed rmyrsed rfformwk rmformwk rlivest rcashcrop rmaize rcatholic livehome ///
	if teso==1 
outreg2 if teso==1 using Table_2.doc, append sum(log) dec(2) title("Table 2" , "Pupil descriptive statistics by ethnic group") ctitle("Teso pupils") eqdrop(N sd max min) keep( age  latrine sibling ironroof transfer crsszone rfyrsed rmyrsed rfformwk rmformwk rlivest rcashcrop livehome rmaize rcatholic) sortvar(age rfyrsed rmyrsed rfformwk rmformwk latrine ironroof rlivest rmaize rcashcrop transfer crsszone livehome sibling rcatholic) addn("1 = Entire Sample, 2 = Luhya pupils, 3 = Teso pupils, 4 = Luo pupils") label
	

summ pupid age   latrine sibling ironroof transfer crsszone ///
	rfyrsed rmyrsed rfformwk rmformwk rlivest rcashcrop rmaize rcatholic livehome ///
   	if luo==1 
outreg2 if luo==1 using Table_2.doc, append sum(log) dec(2) title("Table 2" , "Pupil descriptive statistics by ethnic group") ctitle("Luo pupils") eqdrop(N sd max min) keep( age latrine sibling ironroof transfer crsszone rfyrsed rmyrsed rfformwk rmformwk rlivest rcashcrop livehome rmaize rcatholic) sortvar(age rfyrsed rmyrsed rfformwk rmformwk latrine ironroof rlivest rmaize rcashcrop transfer crsszone livehome sibling rcatholic) addn("1 = Entire Sample, 2 = Luhya pupils, 3 = Teso pupils, 4 = Luo pupils") label


/* NOTE: Proportion of pupil sample is just pupid(N)/5832 */

clear 

/* Check on number of pupils taking 1996 exams by standard */ 
use exam-ethnic_nov00 
gen temp = b1+b2+b3+b4+b5+b6+g1+g2+g3+g4+g5+g6 
summ temp if std==5 
summ temp if std==6 
summ temp if std==7 
summ temp if std==8 
clear 







/* *************************************************************************** */
/* Table 1: Ethnic diversity across geographic divisions in Busia and Teso districts in 1962 and 1996  */ 
/* *************************************************************************** */


 
/* TABLE 1: 1996 Column */ 
use temp_pup 
gen tempdvid = . 
replace tempdvid = 1 if rdvid==4 
replace tempdvid = 2 if rdvid==7 
replace tempdvid = 3 if rdvid==5 
replace tempdvid = 4 if rdvid==2 
replace tempdvid = 5 if rdvid==3 
replace tempdvid = 6 if (rdvid==8 | rdvid==9)
     // here tempdvid is the name of the division variable
collapse luhya teso, by(tempdvid) 
list

clear 



/*TABLE 1: 1962 Column */
use elf_1962
collapse luhya teso, by(division)
list

clear


 


/* End of Table 1 */

/* The reduced-form (rf) regression program */ 
cap program drop comm_rf1 
program def comm_rf1 	
	gen out = `1' 
	regress out rethnic2, robust 
	regress out rethnic2 rteso, robust 
	drop out 
end 

use temp1 

drop religion reslname resfirst 
collapse funds_96 r* schage dist_3 sch_5km totstud pup2tch tchIV yrstch tchsex hmtchIV hmyrssch funyula butula nambale matayos budalang amukura dvid ///
	if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=.), by(zoneid) 

clear 
/* ******************************************************************************* x_ols */










/* **************************************************************************** */
/* TABLE 4: Ethnic diversity and local characteristics                          */
/* **************************************************************************** */


cap program drop comm_rf1 
program def comm_rf1 	
	gen out = `1' 
	drop if (dim1==. | dim2==. | out==. | ethnic2==. | elfA==. | funds_96==. | sc98_press==. | maize==.) 
	
	/* regress out rethnic2, robust cluster(zoneid)  */ 

	gen const=1 
	gen cutoff1=8 
	gen cutoff2=8 

	summ out 

	regress out rethnic2, robust cluster(zoneid)
	
	//regress out rethnic2 rteso, robust cluster(zoneid) 
	
	x_ols dim1 dim2 cutoff1 cutoff2 out const elfA_5km, xreg(2) coord(2) 
	drop epsilon window dis1 dis2 

	//x_ols dim1 dim2 cutoff1 cutoff2 out const elfA_5km rteso, xreg(3) coord(2)
	
clear 
end 

use temp1 

comm_rf1 funds_96 



/* Table 4's variables in order: */

use temp1
drop if (ethnic2==. | elfA==. | funds_96==. | sc98_press==. | maize==.) 
regress fyrsed rethnic2, robust cluster(zoneid)
outreg2  using table_4_1.doc, replace 
comm_rf1 fyrsed 


use temp1 
drop if (ethnic2==. | elfA==. | funds_96==. | sc98_press==. | maize==.) 
regress myrsed rethnic2, robust cluster(zoneid)
outreg2  using table_4_2.doc, replace
comm_rf1 myrsed

use temp1 
drop if (ethnic2==. | elfA==. | funds_96==. | sc98_press==. | maize==.) 
regress fformwk rethnic2, robust cluster(zoneid)
outreg2  using table_4_3.doc, replace
comm_rf1 fformwk 


use temp1
drop if (ethnic2==. | elfA==. | funds_96==. | sc98_press==. | maize==.) 
regress mformwk rethnic2, robust cluster(zoneid)
outreg2  using table_4_4.doc, replace
comm_rf1 mformwk 


use temp1 
drop if (ethnic2==. | elfA==. | funds_96==. | sc98_press==. | maize==.) 
regress latrine rethnic2, robust cluster(zoneid)
outreg2  using table_4_5.doc, replace
comm_rf1 latrine


use temp1 
//regress ironroo rethnic2, robust cluster(zoneid)
//outreg2  using table_4_6.doc, replace
comm_rf1 ironroo 


use temp1 
//regress livest rethnic2, robust cluster(zoneid)
//outreg2  using table_4_7.doc, replace
comm_rf1 livest


use temp1
//regress maize rethnic2, robust cluster(zoneid)
//outreg2  using table_4_8.doc, replace
comm_rf1 maize 


use temp1 
//regress cashcrop rethnic2, robust cluster(zoneid)
//outreg2  using table_4_9.doc, replace
comm_rf1 cashcrop 


use temp1 
//regress sibling rethnic2, robust cluster(zoneid)
//outreg2  using table_4_10.doc, replace
comm_rf1 sibling 


use temp1 
//regress catholic rethnic2, robust cluster(zoneid)
//outreg2  using table_4_11.doc, replace
comm_rf1 catholic


use temp1 
//regress totstud rethnic2, robust cluster(zoneid)
//outreg2  using table_4_12.doc, replace
comm_rf1 totstud 

use temp1 
//regress pup2tch rethnic2, robust cluster(zoneid)
//outreg2  using table_4_13.doc, replace
comm_rf1 pup2tch


use temp1 
//regress tchIV rethnic2, robust cluster(zoneid)
//outreg2  using table_4_14.doc, replace
comm_rf1 tchIV 

use temp1
//regress yrstch rethnic2, robust cluster(zoneid)
//outreg2  using table_4_15.doc, replace
comm_rf1 yrstch

/* NOTE: in paper it is shown as (1-tchsex) */
use temp1 
comm_rf1 tchsex 



/* ******************************************************************************* x_ols */


use temp1 
keep if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.) 

clear 







/* *************************************************************************** */
/* Table 5: Ethnic diversity and local primary school funding                  */ 
/* *************************************************************************** */

/* Part A */

use temp1 

	label variable rethnic2 "Zonal ELF across tribes"
	label variable ethnic2 "School ELF across tribes"
	label variable rethlin  "1 - (Prop... in zone)"
	label variable ethlin "1 - (Prop... in school)"
	label variable ethlin "1 - (Prop... in school)"
	label variable rluhya "Proportion Luhya"
	label variable rteso "Proportion Teso"
	label variable rfformwk "Proportion of fathers with formal employment"
	label variable rlatrine "Proportion of pupils with a latrine at home"
	label variable rlivest "Proportion livestock ownership"
	label variable rcashcrop "Proportion cultivates cash crop"
	
/* OLS 1st Stage (1) */
regress ethnic2 rethnic2, ///
	robust cluster(zoneid) 
estimates store n1
/* OLS (2)*/ 
regress funds_96 ethnic2 ///
	if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), ///
	robust cluster(zoneid) 
estimates store n2
/* RF  IV */ 
/* OLS (3) */
regress funds_96 rethnic2 ///
	if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), ///
	robust cluster(zoneid) 
estimates store n3
/* IV-2sls (4) */
regress funds_96 ethnic2 ///
	(rethnic2) ///
	if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), ///
	robust cluster(zoneid) 
estimates store n4

outreg2 [n1] using Table_5_A.doc, replace bdec(2) sdec(2) nocons title("Table 5.A" , "Ethnic diversity and local primary school funding" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("School ELF", "across tribes", "OLS", "1st stage") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
outreg2 [n2] using Table_5_A.doc, append bdec(1) sdec(1) nocons title("Table 5.A" , "Ethnic diversity and local primary school funding" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("Total local", "OLS") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
outreg2 [n3] using Table_5_A.doc, append bdec(1) sdec(1) nocons title("Table 5.A" , "Ethnic diversity and local primary school funding" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("primary school", "OLS") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
outreg2 [n4] using Table_5_A.doc, append bdec(1) sdec(1) nocons title("Table 5.A" , "Ethnic diversity and local primary school funding" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("funds collected", "IV-2sls") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
estimates clear

/* Part B */	

/* (5) OLS */
regress funds_96 rethnic2 ///
	rfformwk rlatrine rcashcrop rlivest ///
	if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), ///
	robust cluster(zoneid) 
estimates store n1
/* (6) OLS */	
regress funds_96 rethnic2 ///
	rfformwk rlatrine rcashcrop rlivest ///
	funyula butula nambale matayos budalang amukura ///
	rteso ///
	if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), ///
	robust cluster(zoneid) 
estimates store n2
/* (7) OLS */
regress funds_96 rethlin ///
	rfformwk rlatrine rcashcrop rlivest ///
	if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), ///
	robust cluster(zoneid)	
estimates store n3	

outreg2 [n1] using Table_5_B.doc, replace bdec(1) sdec(1) nocons title("Table 5.B" , "Ethnic diversity and local primary school funding" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("OLS") dec(1) keep(rethnic2 ethnic2 rethlin ethlin rluhya rfformwk rlatrine rlivest rcashcrop rteso) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rfformwk rlatrine rlivest rcashcrop rteso) stats(coef se) paren(se) aster(coef) addtext(Geographic division indicators, No) addstat(Root MSE, e(rmse)) label
outreg2 [n2] using Table_5_B.doc, append bdec(1) sdec(1) nocons title("Table 5.B" , "Ethnic diversity and local primary school funding" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("OLS") dec(1) keep(rethnic2 ethnic2 rethlin ethlin rluhya rfformwk rlatrine rlivest rcashcrop rteso) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rfformwk rlatrine rlivest rcashcrop rteso) stats(coef se) paren(se) aster(coef) addtext(Geographic division indicators, Yes) addstat(Root MSE, e(rmse)) label
outreg2 [n3] using Table_5_B.doc, append bdec(1) sdec(1) nocons title("Table 5.B" , "Ethnic diversity and local primary school funding" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("OLS") dec(1) keep(rethnic2 ethnic2 rethlin ethlin rluhya rfformwk rlatrine rlivest rcashcrop rteso) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rfformwk rlatrine rlivest rcashcrop rteso) stats(coef se) paren(se) aster(coef) addtext(Geographic division indicators, No) addstat(Root MSE, e(rmse)) label

	
/* Spatial OLS */	
	
	
	/* see the end of TABLE 6, or look up "From TABLE 5.C" */
	
	
	
	
	
	
	
	
/* *************************************************************************** */
/* Table 6: Ethnic diversity impacts, controlling for ethnic population shares */ 
/* *************************************************************************** */


	label variable rethnic2 "Zonal ELF across tribes"
	label variable ethnic2 "School ELF across tribes"
	label variable rethlin  "1 - (Prop... in zone)"
	label variable ethlin "1 - (Prop... in school)"
	label variable ethlin "1 - (Prop... in school)"
	label variable rluhya "Proportion Luhya"
	label variable rteso "Proportion Teso"

regress funds_96 rethnic2 if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), robust cluster(zoneid)
estimates store n1
regress funds_96 rethnic2 rluhya rteso if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), robust cluster(zoneid)
estimates store n2
regress funds_96 ethnic2 (rethnic2) if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), robust cluster(zoneid)
estimates store n3
regress funds_96 ethnic2 rluhya rteso (rethnic2 rluhya rteso)  if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), robust cluster(zoneid)
estimates store n4
outreg2 [n1] using Table_6_A.doc, replace nocons title("Table 6.A" , "Ethnic diversity impacts controlling for ethnic population shares" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("OLS") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
outreg2 [n2] using Table_6_A.doc, append nocons title("Table 6.A" , "Ethnic diversity impacts controlling for ethnic population shares" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("OLS") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
outreg2 [n3] using Table_6_A.doc, append nocons title("Table 6.A" , "Ethnic diversity impacts controlling for ethnic population shares" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("IV-2sls") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
outreg2 [n4] using Table_6_A.doc, append nocons title("Table 6.A" , "Ethnic diversity impacts controlling for ethnic population shares" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("IV-2sls") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
estimates clear

regress funds_96 rethlin if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), robust cluster(zoneid)
estimates store n1
regress funds_96 rethlin rluhya rteso if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), robust cluster(zoneid)
estimates store n2
regress funds_96 ethlin (rethlin) if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), robust cluster(zoneid)
estimates store n3
regress funds_96 ethlin rluhya rteso (rethlin rluhya rteso)  if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), robust cluster(zoneid)
estimates store n4
outreg2 [n1] using Table_6_B.doc, replace nocons title("Table 6.B" , "Ethnic diversity impacts controlling for ethnic population shares" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("OLS") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
outreg2 [n2] using Table_6_B.doc, append nocons title("Table 6.B" , "Ethnic diversity impacts controlling for ethnic population shares" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("OLS") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
outreg2 [n3] using Table_6_B.doc, append nocons title("Table 6.B" , "Ethnic diversity impacts controlling for ethnic population shares" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("IV-2sls") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label
outreg2 [n4] using Table_6_B.doc, append nocons title("Table 6.B" , "Ethnic diversity impacts controlling for ethnic population shares" , "Dependant variable: total local primary school funds collected per pupil '95 KS") ctitle("IV-2sls") dec(1) sortvar(rethnic2 ethnic2 rethlin ethlin rluhya rteso) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label


/* 1996 Exam Namelist data */ 
gen const=1 
/* Radius 5km, Cut-off 8km */ 
gen cutoff1=8 
gen cutoff2=8 
drop if (dim1==. | dim2==. | funds_96==. | ethnic2==. | elfA==. | sc98_press==. | maize==.) 
save temp2, replace 


/* Drop one zone at a time */ 
local i=1 
while (`i' < 23) { 
	use temp2 
	drop if zoneid==`i' 
	
	regress funds_96 rethnic2 ///
	rfformwk rlatrine rcashcrop rlivest ///
	if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), ///
	robust cluster(zoneid) 	

	clear 

	local i = `i' + 1 
	} 


use temp2 

/* ******************************************************************************* x_ols */







/* *************** */

/* From TABLE 5.C Model 8 SPATIAL OLS */



/* No controls */ 

x_ols dim1 dim2 cutoff1 cutoff2 ///
	funds_96 const elfA_5km, ///
	xreg(2) coord(2) 
regress funds_96 elfA_5km 
clear 


/* SES controls */ 
use temp2 
x_ols dim1 dim2 cutoff1 cutoff2 ///
	funds_96 const elfA_5km ///
	rfformwk rlatrine rcashcrop rlivest, ///
	xreg(6) coord(2) 
regress funds_96 elfA_5km ///
	rfformwk rlatrine rcashcrop rlivest 
clear 

/* *************** */







/* *************************************************************************** */
/* Table 7: Other primary school outcomes                                      */ 
/* *************************************************************************** */

/* The standard IV regression */ 
cap program drop reg_iv 
program def reg_iv 	

	use temp1 
	/* Use namelist ethnicity data */ 
	gen const=1 
	/* Radius 5km, Cut-off 5km */ 
	gen cutoff1=8 
	gen cutoff2=8 

	gen out = `1' 

	drop if (dim1==. | dim2==. | funds_96==. | ethnic2==.| elfA_5km==. | out==. | sc98_press==. | maize==.) 
	save temp2, replace 

summ out 

 
regress out rethnic2 ///
	rfformwk rlatrine rcashcrop rlivest ///
	if (funds_96~=. & ethnic2~=. & elfA~=. & sc98_press~=. & maize~=.), ///
	robust cluster(zoneid) 
 

/* ******************************************************************************* x_ols */

x_ols dim1 dim2 cutoff1 cutoff2 ///
	out const elfA_5km ///
	rfformwk rlatrine rcashcrop rlivest, ///
	xreg(6) coord(2) 
regress out elfA_5km ///
	rfformwk rlatrine rcashcrop rlivest 
clear 

end 

/* ******************************************************************************* x_ols */


				/* IN THE ORDER OF TABLE 7 OF THE PAPER */

reg_iv donation_96

reg_iv fees_96 

/* Desks */
reg_iv desk2pup 

reg_iv  plat2pup

reg_iv room2pup

reg_iv bks2pup

reg_iv text2pup 

reg_iv sch_5km

/* See 7.C, at the end of TABLE 8, or look for "TABLE 7.C */







/* *************************************************************************** */
/* Table 8: School committee records and field officer observations                                     */ 
/* *************************************************************************** */

reg_iv sc98_press

reg_iv sc98_admin 

reg_iv pta98_mtgs 

/* Parent cooperation rated by field officers */ 
reg_iv PRcoop 
/* Teacher motivation rated by field officers */ 
reg_iv TCmoti 

/* end of analysis for TABLE 8 */

clear 

/* Test scores */ 
/* Use 1996 ICS tests: standards 3-8 & high participation rates --> more accurate picture, perhaps */ 
/* Raw data */ 
use 96Test06 
/* Use pupid to assign schoolid, since this was start of project  divide by 10000 and round down */ 
gen temp = pupid/10000 
gen schoolid = int(temp) 
/* Normalize scores by test, standard */ 
egen s96_3e = std(oct96eng) if stdoct96==3 
egen s96_4e = std(oct96eng) if stdoct96==4 
egen s96_5e = std(oct96eng) if stdoct96==5 
egen s96_6e = std(oct96eng) if stdoct96==6 
egen s96_7e = std(oct96eng) if stdoct96==7 
egen s96_8e = std(oct96eng) if stdoct96==8 

egen s96_3m = std(oct96mat) if stdoct96==3 
egen s96_4m = std(oct96mat) if stdoct96==4 
egen s96_5m = std(oct96mat) if stdoct96==5 
egen s96_6m = std(oct96mat) if stdoct96==6 
egen s96_7m = std(oct96mat) if stdoct96==7 
egen s96_8m = std(oct96mat) if stdoct96==8 

egen s96_3s = std(oct96sci) if stdoct96==3 
egen s96_4s = std(oct96sci) if stdoct96==4 
egen s96_5s = std(oct96sci) if stdoct96==5 
egen s96_6s = std(oct96sci) if stdoct96==6 
egen s96_7s = std(oct96sci) if stdoct96==7 
egen s96_8s = std(oct96sci) if stdoct96==8 

gen s96_3t = s96_3e+s96_3m+s96_3s 
gen s96_4t = s96_4e+s96_4m+s96_4s 
gen s96_5t = s96_5e+s96_5m+s96_5s 
gen s96_6t = s96_6e+s96_6m+s96_6s 
gen s96_7t = s96_7e+s96_7m+s96_7s 
gen s96_8t = s96_8e+s96_8m+s96_8s 

egen s96_3 = std(s96_3t) 
egen s96_4 = std(s96_4t) 
egen s96_5 = std(s96_5t) 
egen s96_6 = std(s96_6t) 
egen s96_7 = std(s96_7t) 
egen s96_8 = std(s96_8t) 

gen s96 = . 
replace s96 = s96_3 if s96_3~=. 
replace s96 = s96_4 if s96_4~=. 
replace s96 = s96_5 if s96_5~=. 
replace s96 = s96_6 if s96_6~=. 
replace s96 = s96_7 if s96_7~=. 
replace s96 = s96_8 if s96_8~=. 
/* Create indicators by grade in 1996 */ 
gen tk96_3 = . 
replace tk96_3 = 1 if s96_3~=. 
gen tk96_4 = . 
replace tk96_4 = 1 if s96_4~=. 
gen tk96_5 = . 
replace tk96_5 = 1 if s96_5~=. 
gen tk96_6 = . 
replace tk96_6 = 1 if s96_6~=. 
gen tk96_7 = . 
replace tk96_7 = 1 if s96_7~=. 
gen tk96_8 = . 
replace tk96_8 = 1 if s96_8~=. 
/* Collapse into school averages */ 
collapse (mean) s96* (count) tk96*, by(schoolid) 
drop if schoolid>199 
drop s96_3e-s96_8t 
sort schoolid 
save f1, replace 
clear 

use temp1 
drop s9* 
sort schoolid 
merge schoolid using f1 
tab _merge 
drop _merge 
gen tk96 = tk96_3+tk96_4+tk96_5+tk96_6+tk96_7+tk96_8 
/* Control for proportion of pupils taking the exam in 1996 */ 
gen e6 = real(e3_96_6) 
gen e7 = real(e3_96_7) 
gen e8 = real(e3_96_8) 
gen enr38_96 = e3_96_3+e3_96_4+e3_96_5+e6+e7+e8 
gen prtest96 = tk96/enr38_96 
summ s96* tk96* prtest* 
save temp1, replace 

/* Use namelist ethnicity data */ 
gen const=1 
/* Radius 5km, Cut-off 5km */ 
gen cutoff1=8 
gen cutoff2=8 

keep if (ethnic2~=. & elfA_5km~=. & funds_96~=. & sc98_press~=. & maize~=.) 

summ s96 
	
	/* SAME AS REG_IV ABOVE, EXCEPT INCLUDE SAP CONTROL */ 
	drop if (dim1==. | dim2==. | funds_96==. | ethnic2==.| elfA_5km==. | s96==. | sc98_press==. | maize==.) 
	save temp2, replace 

regress test95 rethnic2 sap1, ///
	robust cluster(zoneid) 
regress s96 rethnic2 sap1, ///
	robust cluster(zoneid) 
	
	
	
	
	
	
/*  TABLE 7.C   */

regress s96 rethnic2 sap1 ///
	rfformwk rlatrine rcashcrop rlivest, ///
	robust cluster(zoneid) 
	

/*    TABLE 7.C      */

/* SES controls */ 
use temp2 
x_ols dim1 dim2 cutoff1 cutoff2 ///
	s96 const elfA_5km sap1 ///
	rfformwk rlatrine rcashcrop rlivest, ///
	xreg(7) coord(2) 
regress s96 elfA_5km sap1 ///
	rfformwk rlatrine rcashcrop rlivest 
clear 





/* *************************************************************************** */
/*                             FIGURES                                         */ 
/* *************************************************************************** */


/* ******************************************************************************* x_ols */


use temp1 
drop if (funds_96==. | ethnic2==.| elfA_5km==. | sc98_press==. | maize==.) 
drop if zoneid==. 

gen tempelf = ethnic2 
gen tempfund = funds_96 
label var tempelf  "School ELF (Luhyas one group)" 
label var tempfund "Local funds/pupil (KSh) 1995" 
qui regress tempfund tempelf 
predict fundshat 
graph7 tempfund fundshat tempelf, ///
	c(.s) s(oi) saving(fig3_schools, replace) ///
	ylabel(0, 100, 200, 300, 400) xlabel(0, .3, .6) 

collapse 	funds_96 donat1 fees1 tempscf desk2pup bks2pup pbks2pup text2pup test95 room2pup plat2pup rethnic1 rethnic2 rethnic3 rluhya rluo rteso rkhayo rmarachi rnyala rsamia budalang butula funyula matayos nambale amukura angurai, ///
		by(zoneid) 

gen tempfund = funds_96 
gen tempelf  = rethnic2 
label var tempelf  "Zonal ELF (Luhyas one group)" 
label var tempfund "Local funds/pupil (KSh) 1995" 
qui regress tempfund tempelf 
predict fundshat 
graph7 tempfund fundshat tempelf, ///
	c(.s) s(oi) saving(figure3, replace) ylabel(0, 100, 200, 300) xlabel(0, .3, .6) 
drop tempfund fundshat 
clear 

use temp1 
drop if (funds_96==. | ethnic2==.| elfA_5km==. | sc98_press==. | maize==.) 
drop if zoneid==. 

collapse 	funds_96 donat1 fees1 tempscf desk2pup bks2pup pbks2pup text2pup test95 room2pup plat2pup rethnic1 rethnic2 rethnic3 rluhya rluo rteso rkhayo rmarachi rnyala rsamia budalang butula funyula matayos nambale amukura angurai, ///
		by(zoneid) 

gen tempfund = funds_96 
label var tempfund "Local funds/pupil (KSh) 1995" 
label var rteso "Proportion of Teso Pupils" 
gen rteso_2 = rteso^2 
qui regress funds_96 rteso rteso_2 
predict tesohat 
graph7 tempfund tesohat rteso, ///
	c(.s) s(oi) saving(figure4, replace) ///
	xlabel(0, .5, 1) ylabel(0, 100, 200, 300) 
clear 


/* SEE WATER.DO FOR THE REST OF THE ANALYSIS: TABLES 9 & 10 */

log c 
