/* Run after kenya_ethnic_analysis.do to reproduce Tables 9 and 10 
in paper "Ethnic diversity, social sanctions, and public goods in Kenya" */ 


/* *************************************************************************** */
/* *********************    -FIRST STEPS-    ********************************* */
/* *************************************************************************** */

cap log close
clear
set more off
set mem 10g


/* CHANGE TO REFLECT WORKING DIRECTORY */
cd "C:\Users\Elisa Cascardi\Desktop\Ethnic Diversity_Replication"

/* do not change - looking in data folder */
cd data\

#delimit ;
log using kefinco_14jun02, replace t;


/* ANALYZE KEFINCO WELL DATA */;

/* Use ethnic diversity within K km around each well */;
use well-ethnic_jun02;
sort wellid;
save, replace;
clear;

insheet using kefinco-data_23aug01.csv;
/* CONVERT COORDINATES INTO DECIMAL DEGREES - FROM KEFINCO-MGB */;
/* CHECK IF NORTH EAST STORED AS STRINGS */;
describe;

/*DECOMPOSING STRING AND ADDING UP TO GET NEW VARIABLES*/
gen byte degreen = real(substr(north,1,2));
gen byte degreee = real(substr(east,1,3));
gen str2 minuten = substr(north,4,5);
gen str2 minutee = substr(east,5,6);
gen str3 secn = substr(north,7,9);
gen str3 sece = substr(east,8,10);

gen nmin = real(minuten);
gen emin = real(minutee);

gen nsec = real(secn);
gen esec = real(sece);

/*CONVERT SECONDS TO MINUTES*/
gen fracminn = nsec/1000;
gen fracmine = esec/1000;

gen totminn = nmin + fracminn;
gen totmine = emin + fracmine;

/*ADD MINUTES TO DEGREES*/
gen dgnorth = totminn/60;
gen dgeast = totmine/60;

gen newnorth = degreen + dgnorth;
gen neweast = degreee + dgeast;

/*DOUBLE CHECK NEW VARIABLES*/
summ degreen nmin nsec fracminn totminn dgnorth newnorth;
summ degreee emin esec fracmine totmine dgeast neweast;

gen str9 oldnorth = north;
gen str10 oldeast = east;
 
drop north east minuten secn degreen nmin nsec fracminn totminn dgnorth degreee
minutee sece emin esec fracmine totmine dgeast;

gen north = newnorth;
gen east = neweast;
drop newnorth neweast;

/* SAVE WITH NEW COORDINATES */; 
save kefinco_jun02, replace;

sort wellid;
merge wellid using well-ethnic_jun02;
tab _merge;
drop _merge;

sort division;
/* Only consider non-Busia Town schools */;
drop if division =="BUSIA TOWNSHIP";
/* Drop if missing division, very few */;
drop if division=="";
/* Use same division indicators as the TRIBES paper */;
replace division = "ANGURAI/AMAGORO" if (division=="ANGURAI" | division=="AMAGORO");
replace division = "AMUKURA/CHAKOL" if (division=="AMUKURA" | division=="CHAKOL");

tab division, gen(Idiv);
drop Idiv1;

/* Create outcome variables */;
/* Does the bore hole work? */;
gen works1 = 2-works;
/* Does the bore hole have normal water flow? Set to zero if low water flow */;
gen works2 = works1;
replace works2 = 0 if wtr_flow == 2;

/* If well does not work, count water purification as zero */;
gen wtr_pur2 = 2-wtr_pur;
replace wtr_pur2 = 0 if works==2;

/* Any parts broken or missing */;
gen any_brms = 0;
gen temp = max(hand_br, top_br, foot_br, epipe_br, seal_br, other_br,
	hand_ms, top_ms, foot_ms, epipe_ms, other_ms);
replace any_brms = 1 if (temp == 1);
gen no_brms = 1 - any_brms;
drop temp;

/* People get water from another bore hole or well */;
/* Only consider those wells that are NOT working well (works2==0) */;
gen oth_bh = 0;
replace oth_bh = 1 if (source==3 | source==5 | srce_oth=="3" | srce_oth=="5");
replace oth_bh = . if (source==.);
replace oth_bh = . if (works2==1 | works2==.);

/* Construct information date when the wells failed */;
gen str10 temp = yr_stop;
replace temp = "." if (yr_stop=="DK" | yr_stop=="90S" | yr_stop=="LATE 70S" | yr_stop=="9999");
replace temp = "1988" if yr_stop=="LATE 80S";
gen yr_stop2 = real(temp);
replace yr_stop2 = . if (works2==1 | works2==.);

save kefinco_jun02, replace;







/* *************************************************************************** */;
/* TABLE 9: Well descriptive statistics                                        */;
/* *************************************************************************** */;



	label variable elf_5km "ELF...5 km from well";
	label variable works2  "Indic...normal water flow";
	label variable no_brms "Indic.... no broken/missing";
	label variable oth_bh "Indic... another well";
	label variable yr_stop2 "Year well stopped";
	label variable north "Latitude (north)";
	label variable east "Longitude (east)";
	
	
/* Summary statistics */;
summ works* wtr* any* no* north east elf* if (elf_5km~=. & works~=. & any_brms~=.);
summ oth_bh yr_stop2 if (elf_5km~=. & oth_bh~=. & yr_stop2~=.);
outreg2 if (elf_5km~=. & works~=. & any_brms~=.) using Table_9.doc, replace sum(log) dec(2) title("Table 9" , "Well descriptive statistics")  eqdrop(max min) keep(elf_5km works2 no_brms north east) sortvar(elf_5km works2 no_brms oth_bh yr_stop2 north east)  label;
outreg2 if (elf_5km~=. & oth_bh~=. & yr_stop2~=.) using Table_9.doc, append sum(log) dec(2) title("Table 9" , "Well descriptive statistics")  eqdrop(max min) keep(oth_bh yr_stop2) sortvar(elf_5km works2 no_brms oth_bh yr_stop2 north east)  label;






/* *************************************************************************** */;
/*             TABLE 10: Ethnic diversity and well maintenance                 */;
/* *************************************************************************** */;


/* Creating programs used in analysis */


cap program drop reg_bas;
program def reg_bas;	
	label variable elf_5km "ELF...5 km from well";

	gen out = `1';
	dprobit out elf_5km, robust;
	regress out elf_5km, robust;
	regress out elf_5km Idiv*, robust;
	regress out elf_3km, robust;
	regress out elf_7km, robust;
	drop out;
end;

/*** Basic OLS regression II, non-discrete variables ***/;
cap program drop reg_bas2;
program def reg_bas2;
	label variable elf_5km "ELF...5 km from well";

	gen out = `1';
	regress out elf_5km, robust;
	regress out elf_5km Idiv*, robust;
	regress out elf_7km, robust;
	drop out;
end;


reg_bas works1;
reg_bas wtr_pur2;
clear;


cap program drop reg5;
program def reg5;
	label variable elf_5km "ELF...5 km from well";

	gen out = `1';
	drop if (dim1==. | dim2==. | out==. | elf_5km==. | Idiv2==.);
	gen const=1;
	gen cutoff1=7;
	gen cutoff2=7;
	
	x_ols dim1 dim2 cutoff1 cutoff2
	out const elf_5km,
	xreg(2) coord(2);
	/* Division indicators */;
	drop epsilon window dis1 dis2;
	x_ols dim1 dim2 cutoff1 cutoff2
	out const elf_5km Idiv*,
	xreg(8) coord(2);

	/* Robustness to different threshold */;
	drop epsilon window dis1 dis2;
	replace cutoff1=9;
	replace cutoff2=9;
	x_ols dim1 dim2 cutoff1 cutoff2
	out const elf_5km,
	xreg(2) coord(2);
	

	clear;
end;

cap program drop reg37;
program def reg37;

	gen out = `1';
	drop if (dim1==. | dim2==. | out==. | elf_3km==. | elf_7km==. | Idiv2==.);
	gen const=1;
	gen cutoff1=5;
	gen cutoff2=5;
	
	x_ols dim1 dim2 cutoff1 cutoff2
	out const elf_3km,
	xreg(2) coord(2);

	drop epsilon window dis1 dis2;
	replace cutoff1=9;
	replace cutoff2=9;
	x_ols dim1 dim2 cutoff1 cutoff2
	out const elf_7km,
	xreg(2) coord(2);

	clear;
end;

	
use kefinco_jun02;
drop if (works2==. | no_brms==.);
label variable elf_5km "ELF...5 km from well";
dprobit works2 elf_5km, robust;
outreg2 using Table_10.doc, replace nocons title("Table 10 (PROBIT)" , "Ethnic diversity and well maintenance") ctitle("Normal water flow", "Probit") dec(2) keep(elf_5km) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label;
reg_bas works2;
reg5 works2;



/* Any part broken/missing for all wells */;
clear;
use kefinco_jun02;
drop if (works2==. | no_brms==.);
label variable elf_5km "ELF...5 km from well";
dprobit no_brms elf_5km, robust;
outreg2 using Table_10.doc, append nocons title("Table 10 (PROBIT)" , "Ethnic diversity and well maintenance") ctitle("No broken or " , "missing well parts", "Probit") dec(2) keep(elf_5km) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label;
reg_bas no_brms;
reg5 no_brms;


clear;
use kefinco_jun02;
drop if (yr_stop2==. | oth_bh==.);
label variable elf_5km "ELF...5 km from well";
dprobit oth_bh elf_5km, robust;
outreg2 using Table_10.doc, append nocons title("Table 10 (PROBIT)" , "Ethnic diversity and well maintenance") ctitle("Get water from" , "another local well", "Probit") dec(2) keep(elf_5km) stats(coef se) paren(se) aster(coef) addstat(Root MSE, e(rmse)) label;
reg_bas oth_bh;
reg5 oth_bh;
 

log c;
